@@ -577,7 +577,10 @@ class Witter():
                 f5.write("replyTo" + str(counter) + " = " +store.get_value(item,7)+"\n")
                 f5.write("source" + str(counter) + " = " +store.get_value(item,8)+"\n")
                 #9 is avatar pic
-                f5.write("formattedTweet" + str(counter) + " = " +store.get_value(item,10)+"\n")
+                formattedTweet = store.get_value(item,10)
+                formattedTweet = formattedTweet.replace("\n","&CR;")
+                f5.write("formattedTweet" + str(counter) + " = " +formattedTweet+"\n")
+                
                 item = store.iter_next(item)
                 counter= counter+1
                 
@@ -602,6 +605,7 @@ class Witter():
                 type = config.get("tweets", "type" + str(counter));
                 source = config.get("tweets", "source" + str(counter));
                 formattedTweet = config.get("tweets", "formattedTweet" + str(counter));
+                formattedTweet = formattedTweet.replace("&CR;", "\n")
                 #load avatar
                 filename = senderId+".jpg"
                 if (os.path.isfile("/home/user/.witterPics/" + self.activeAccount.accountdata.servicename + "/" + filename)):
